==> nextcloud-25.0.12p1.tgz: nextcloud/apps/activity/l10n/es_GT.js <==
OC.L10N.register(
    "activity",
    {
    "Copied!" : "¡Copiado!",
    "Not supported!" : "¡No soportado!",
    "Press ⌘-C to copy." : "Presiona ⌘-C para copiar.",
    "Press Ctrl-C to copy." : "Presiona Ctrl-C para copiar.",
    "{name} (invisible)" : "{name} (invisible)",
    "{name} (restricted)" : "{name} (restringido)",
    "Home" : "Inicio",
    "in {path}" : "en {path}",
    "This stream will show events like additions, changes & shares" : "Este flujo mostrará eventos tales como añadir, cambiar & compartir",
    "There are no events for this filter" : "No hay eventos para este filtro",
    "Today" : "Hoy",
    "Yesterday" : "Ayer",
    "Open {filename}" : "Abierto {filename}",
    "Activity" : "Actividad",
    "Personal activity feed for %s" : "Fuente de actividad personal para %s",
    "Your feed URL is invalid" : "La URL de tu fuente de es inválida",
    "Your settings have been updated." : "Tus configuraciones se han actualizado.",
    "Settings have been updated." : "Las configuraciones han sido actualizadas",
    "Recent activity" : "Actividad reciente",
    "No activities" : "No hay actividades",
    "More activities" : "Más actividades",
    "_and %n more _::_and %n more _" : ["y %n más","y %n más","y %n más"],
    "All activities" : "Todas las actividades",
    "By others" : "Por otros",
    "By you" : "Por usted",
    "Hello %s" : "Hola %s",
    "Hello %s," : "Hola %s,",
    "There was some activity at %s" : "Se tuvo algo de actividad en %s",
    "Mail" : "Correo",
    "Notifications" : "Notificaciones",
    "Send email" : "Enviar correo electrónico",
    "You need to set up your email address before you can receive notification emails." : "Necesitas configurar tu dirección de correo electrónico antes de que puedas recibir correos de notificación",
    "Send activity emails" : "Enviar correos de actividades",
    "As soon as possible" : "Lo antes posible",
    "Hourly" : "Cada hora",
    "Daily" : "Diariamente",
    "Weekly" : "Semanalmente",
    "No activity yet" : "Aún no tiene actividad",
    "Notification" : "Notificación",
    "Default settings" : "Configuraciones predeterminadas",
    "Activity feed" : "Fuente de actividad",
    "Enable RSS feed" : "Habilitar fuente RSS",
    "RSS feed" : "Fuente RSS",
    "No more events to load" : "No hay más eventos por cargar",
    "Activities" : "Actividades"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-27.1.11.tgz: nextcloud/apps/activity/l10n/es_GT.js <==
OC.L10N.register(
    "activity",
    {
    "Personal activity feed for %s" : "Fuente de actividad personal para %s",
    "Your feed URL is invalid" : "La URL de tu fuente de es inválida",
    "Activity feed" : "Fuente de actividad",
    "Your settings have been updated." : "Tus configuraciones se han actualizado.",
    "Settings have been updated." : "Las configuraciones han sido actualizadas",
    "Recent activity" : "Actividad reciente",
    "No activities" : "No hay actividades",
    "More activities" : "Más actividades",
    "_and %n more _::_and %n more _" : ["y %n más","y %n más","y %n más"],
    "All activities" : "Todas las actividades",
    "By others" : "Por otros",
    "By you" : "Por usted",
    "Hello %s" : "Hola %s",
    "Hello %s," : "Hola %s,",
    "There was some activity at %s" : "Se tuvo algo de actividad en %s",
    "Mail" : "Correo",
    "Activity" : "Actividad",
    "Notifications" : "Notificaciones",
    "Send email" : "Enviar correo electrónico",
    "Today" : "Hoy",
    "Yesterday" : "Ayer",
    "You need to set up your email address before you can receive notification emails." : "Necesitas configurar tu dirección de correo electrónico antes de que puedas recibir correos de notificación",
    "Send activity emails" : "Enviar correos de actividades",
    "As soon as possible" : "Lo antes posible",
    "Hourly" : "Cada hora",
    "Daily" : "Diariamente",
    "Weekly" : "Semanalmente",
    "You commented" : "Comentaste",
    "Open {filename}" : "Abierto {filename}",
    "in {path}" : "en {path}",
    "Home" : "Inicio",
    "This stream will show events like additions, changes & shares" : "Este flujo mostrará eventos tales como añadir, cambiar & compartir",
    "No activity yet" : "Aún no tiene actividad",
    "Enable RSS feed" : "Habilitar fuente RSS",
    "RSS feed" : "Fuente RSS",
    "Notification" : "Notificación",
    "Default settings" : "Configuraciones predeterminadas",
    "No more events to load" : "No hay más eventos por cargar",
    "Copied!" : "¡Copiado!",
    "Not supported!" : "¡No soportado!",
    "Press ⌘-C to copy." : "Presiona ⌘-C para copiar.",
    "Press Ctrl-C to copy." : "Presiona Ctrl-C para copiar.",
    "{name} (invisible)" : "{name} (invisible)",
    "{name} (restricted)" : "{name} (restringido)",
    "There are no events for this filter" : "No hay eventos para este filtro"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
